@@ -1,4 +1,4 @@
-drake_backend.loop <- function(config) {
+drake_backend_loop <- function(config) {
   config$envir_loop <- new.env(parent = emptyenv())
   config$envir_loop$targets <- igraph::topo_sort(config$envir_graph$graph)$name
   while (length(config$envir_loop$targets)) {
