@@ -1284,7 +1284,7 @@ test_with_dir("dyn loadd/readd with NULL subtargets (#1139)", {
 test_with_dir("dynamic hpc", {
   skip_on_cran()
   skip_on_os("windows")
-  skip_if_not_installed("clustermq")
+  skip_if_not_installed("clustermq", minimum_version = "0.9.1")
   skip_if_not_installed("future")
   if ("package:clustermq" %in% search()) {
     detach("package:clustermq", unload = TRUE) # nolint
